pyparsing.pyparsing.Word

Package pyparsing :: Module pyparsing :: Class Word |
[frames | no frames]

## Type Word

       object --+
                |
    ParserElement --+
                    |
                Token --+
                        |
                       Word

Token for matching words composed of allowed character sets. Defined with string containing all allowed initial characters, an optional string containing allowed body characters (if omitted, defaults to the initial character set), and an optional minimum, maximum, and/or exact length. The default value for min is 1 (a minimum value < 1 is not valid); the default values for max and exact are 0, meaning no maximum or exact length restriction.

Method Summary
| `__init__(self, initChars, bodyChars, min, max, exact, asKeyword)`
| `__str__(self)`
| `parseImpl(self, instring, loc, doActions)`
Inherited from `Token`: `setName` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__invert__`, `__mul__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `enablePackrat`, `getException`, `ignore`, `leaveWhitespace`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `streamline`, `suppress`, `transformString`, `tryParse`, `validate` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
`list` | `__slotnames__` = `[]`
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Class Variable Details

    ### __slotnames__ Type: `list` Value:
        []

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net